@@ -103,6 +103,9 @@ namespace GEO {
         /** \brief Pointer to unsigned byte(s) */
         typedef byte* pointer;
 
+        /** \brief Const pointer to unsigned byte(s) */
+        typedef const byte* const_pointer;
+
         /** \brief Generic function pointer */
         typedef void (*function_pointer)();
 
@@ -136,12 +139,12 @@ namespace GEO {
          *  and generic pointers using casts. Such conversion may be
          *  required when retrieving symbols in dynamically linked libraries,
          *  or when interfacing with scripting languages.
+	 * \tparam FPTR function pointer type
          * \param[in] fptr the function pointer
          * \return a generic pointer with the same address as \p fptr
          */
-        inline pointer function_pointer_to_generic_pointer(
-            function_pointer fptr
-        ) {
+	template <class FPTR=function_pointer>
+	inline pointer function_pointer_to_generic_pointer(FPTR fptr) {
             // I know this is ugly, but I did not find a simpler warning-free
             // way that is portable between all compilers.
             pointer result = nullptr;
@@ -155,15 +158,15 @@ namespace GEO {
          *  and generic pointers using casts. Such conversion may be required
          *  when retrieving symbols in dynamically linked libraries, or when
          *  interfacing with scripting languages.
+	 * \tparam FPTR function pointer type
          * \param[in] ptr the generic pointer
          * \return a function pointer with the same address as \p ptr
          */
-        inline function_pointer generic_pointer_to_function_pointer(
-            pointer ptr
-        ) {
+        template <class FPTR = function_pointer>
+	inline FPTR generic_pointer_to_function_pointer(pointer ptr) {
             // I know this is ugly, but I did not find a simpler warning-free
             // way that is portable between all compilers.
-            function_pointer result = nullptr;
+            FPTR result = nullptr;
             ::memcpy(&result, &ptr, sizeof(pointer));
             return result;
         }
@@ -174,17 +177,57 @@ namespace GEO {
          *  and generic pointers using casts. Such conversion may be
          *  required when retrieving symbols in dynamically linked libraries,
          *  or when interfacing with scripting languages.
+	 * \tparam FPTR function pointer type
          * \param[in] ptr the generic pointer
          * \return a function pointer with the same address as \p ptr
          */
-        inline function_pointer generic_pointer_to_function_pointer(void* ptr) {
+        template <class FPTR = function_pointer>
+        inline FPTR generic_pointer_to_function_pointer(void* ptr) {
             // I know this is ugly, but I did not find a simpler warning-free
             // way that is portable between all compilers.
-            function_pointer result = nullptr;
+            FPTR result = nullptr;
             ::memcpy(&result, &ptr, sizeof(pointer));
             return result;
         }
 
+
+	/**
+	 * \brief Converts a pointer to a reference
+	 * \tparam T the type for the reference
+	 * \param[in] ptr the pointer
+	 * \return a reference of type T&
+	 */
+	template <class T> inline T& pointer_as_reference(void* ptr) {
+	    // This is the recommended way of converting between pointers
+	    // of different types. Casting the pointer directly is undefined
+	    // behavior. Note: the call to memcpy() is eliminated by the
+	    // compiler (that generates the same thing as when casting the
+	    // pointer).
+	    T* T_ptr;
+	    ::memcpy(&T_ptr, &ptr, sizeof(pointer));
+	    return *T_ptr;
+	}
+
+	/**
+	 * \brief Converts a const pointer to a reference
+	 * \tparam T the type for the reference
+	 * \param[in] ptr the pointer
+	 * \return a const reference of type const T&
+	 */
+	template <class T> inline const T& pointer_as_reference(
+	    const void* ptr
+	) {
+	    // This is the recommended way of converting between pointers
+	    // of different types. Casting the pointer directly is undefined
+	    // behavior. Note: the call to memcpy() is eliminated by the
+	    // compiler (that generates the same thing as when casting the
+	    // pointer).
+	    const T* T_ptr;
+	    ::memcpy(&T_ptr, &ptr, sizeof(pointer));
+	    return *T_ptr;
+	}
+
+
         /**
          * \brief Default memory alignment for efficient vector operations
          * \details The memory alignment is given in bytes. Here is a list of
@@ -487,9 +530,18 @@ namespace GEO {
             template <class U>
             struct rebind {
                 /** Equivalent allocator type to allocate elements of type \p U*/
-                typedef aligned_allocator<U> other;
+                typedef aligned_allocator<U,ALIGN> other;
             };
 
+            /* \brief default constructor */
+            constexpr aligned_allocator() noexcept = default;
+
+            /* \brief conversion copy constructor */
+            template <class U, int A2> constexpr aligned_allocator(
+		const aligned_allocator<U, A2>&
+	    ) noexcept {
+	    }
+
             /**
              * \brief Gets the address of an object
              * \param[in] x a reference to an object of type T
@@ -608,10 +660,8 @@ namespace GEO {
              * \see deallocate()
              */
             void destroy(pointer p) {
+		geo_argused(p); // else MSVC complains
                 p->~value_type();
-#ifdef GEO_COMPILER_MSVC
-                (void) p; // to avoid a "unreferenced variable" warning
-#endif
             }
 
             /**
