@@ -13,7 +13,7 @@
  *  * Neither the name of the ALICE Project-Team nor the names of its
  *  contributors may be used to endorse or promote products derived from this
  *  software without specific prior written permission.
- * 
+ *
  *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -102,7 +102,7 @@ namespace GEO {
             std::vector<std::string>& out,
             bool skip_empty_fields = true
         );
-        
+
         /**
          * \brief Splits a string into two parts.
          * \param[in] in the input string to split
@@ -122,7 +122,7 @@ namespace GEO {
             std::string& left,
             std::string& right
         );
-        
+
         /**
          * \brief Join multiple strings
          * \details Joins all the strings in list \p in into a single string
@@ -214,20 +214,28 @@ namespace GEO {
         );
 
         /**
-         * \brief Creates a string from a format string and additional 
+         * \brief Creates a string from a format string and additional
          *  arguments. Works like sprintf()
          * \param[in] format the format string
-         */ 
+         */
         std::string GEOGRAM_API format(const char* format, ...)
-#ifndef GOMGEN            
+#ifndef GOMGEN
 #ifdef GEO_COMPILER_GCC_FAMILY
         // Tells the compiler that format is a printf-like format
         // string, so that it can check that the arguments match
         // the format string and bark at you if it is not the case.
-        __attribute__ ((__format__(printf, 1, 2)))
+            __attribute__ ((__format__(printf, 1, 2)))
 #endif
-#endif            
-        ; 
+#endif
+            ;
+
+	/**
+	 * \brief Converts a time in seconds into a human-readable string
+	 * \param[in] HMS_only if set, always returns a hh:mm:ss string,
+	 *  else returns the time in seconds and a (hh:mm:ss) if time is
+	 *  greater or equal to one minute.
+	 */
+	std::string GEOGRAM_API format_time(double seconds, bool HMS_only=false);
 
         /**
          * \brief Converts a typed value to a string
@@ -237,55 +245,55 @@ namespace GEO {
         template <class T>
         inline std::string to_string(const T& value) {
             std::ostringstream out;
-	    // Makes sure that double-precision number are displayed
-	    // with a sufficient number of digits. This is important
-	    // to avoid losing precision when using ASCII files.
-	    out << std::setprecision(17);
+            // Makes sure that double-precision number are displayed
+            // with a sufficient number of digits. This is important
+            // to avoid losing precision when using ASCII files.
+            out << std::setprecision(17);
             out << value;
             return out.str();
         }
 
         /**
          * \brief Converts a typed value to a string for display.
-	 * \details Does not keep all significant digits for floating point
-	 *   numbers.
+         * \details Does not keep all significant digits for floating point
+         *   numbers.
          * \param[in] value the typed value to convert
          * \return a string that contain the stringified form of the value
          */
         template <class T>
         inline std::string to_display_string(const T& value) {
-	    return to_string(value);
-	}
+            return to_string(value);
+        }
 
 
         /**
          * \brief Converts a typed value to a string for display.
-	 * \details Does not keep all significant digits for floating point
-	 *   numbers.
+         * \details Does not keep all significant digits for floating point
+         *   numbers.
          * \param[in] value the typed value to convert
          * \return a string that contain the stringified form of the value
          */
         template <>
         inline std::string to_display_string(const double& value) {
-            std::ostringstream out;	    
+            std::ostringstream out;
             out << value;
             return out.str();
-	}
+        }
 
         /**
          * \brief Converts a typed value to a string for display.
-	 * \details Does not keep all significant digits for floating point
-	 *   numbers.
+         * \details Does not keep all significant digits for floating point
+         *   numbers.
          * \param[in] value the typed value to convert
          * \return a string that contain the stringified form of the value
          */
         template <>
         inline std::string to_display_string(const float& value) {
-            std::ostringstream out;	    
+            std::ostringstream out;
             out << value;
             return out.str();
-	}
-	
+        }
+
         /**
          * \brief Converts a boolean value to a string
          * \param[in] value the boolean value to convert
@@ -516,16 +524,16 @@ namespace GEO {
         template <>
         inline bool from_string(const char* s, bool& value) {
             if(strcmp(s, "true") == 0 ||
-                strcmp(s, "True") == 0 ||
-                strcmp(s, "1") == 0
-            ) {
+               strcmp(s, "True") == 0 ||
+               strcmp(s, "1") == 0
+              ) {
                 value = true;
                 return true;
             }
             if(strcmp(s, "false") == 0 ||
-                strcmp(s, "False") == 0 ||
-                strcmp(s, "0") == 0
-            ) {
+               strcmp(s, "False") == 0 ||
+               strcmp(s, "0") == 0
+              ) {
                 value = false;
                 return true;
             }
@@ -600,14 +608,13 @@ namespace GEO {
             return value;
         }
 
-	/**
-	 * \brief Converts a wide char string into an UTF8 string.
-	 * \param[in] in the input null-terminated wide-char string.
-	 * \return the UTF8-encoded string in a std::string.
-	 */
-	std::string GEOGRAM_API wchar_to_UTF8(const wchar_t* in);
+        /**
+         * \brief Converts a wide char string into an UTF8 string.
+         * \param[in] in the input null-terminated wide-char string.
+         * \return the UTF8-encoded string in a std::string.
+         */
+        std::string GEOGRAM_API wchar_to_UTF8(const wchar_t* in);
     }
 }
 
 #endif
-
