@@ -1225,16 +1225,14 @@ namespace GEO {
          * \brief Implementation of the wrapper.
          * \details This is the C functions to be declared to LUA.
          *  It is typed by the signature of the wrapped C++ function,
-         *  and the pointer to the  actual wrapped C++ function is stored
+         *  and the pointer to the actual wrapped C++ function is stored
          *  in an upvalue.
          * \param[in] L a pointer to the LUA state.
          */
         static int call(lua_State* L) {
-            FPTR f = FPTR(
-                Memory::generic_pointer_to_function_pointer(
-                    lua_touserdata(L, lua_upvalueindex(1))
-                )
-            );
+            FPTR f = Memory::generic_pointer_to_function_pointer<FPTR>(
+		lua_touserdata(L, lua_upvalueindex(1))
+	    );
             return lua_wrap(L, f);
         }
 
@@ -1246,10 +1244,7 @@ namespace GEO {
          */
         static void push(lua_State* L, FPTR f) {
             lua_pushlightuserdata(
-                L,
-                Memory::function_pointer_to_generic_pointer(
-                    Memory::function_pointer(f)
-                )
+                L, Memory::function_pointer_to_generic_pointer<FPTR>(f)
             );
             lua_pushcclosure(L, lua_wrapper<FPTR>::call, 1);
         }
